@@ -1,6 +1,6 @@
 /*
  * This file is part of rvg.
- * Copyright (c) 2016, David Gohel All rights reserved.
+ * Copyright (c) 2018, David Gohel All rights reserved.
  *
  * rvg is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with rvg. If not, see <http://www.gnu.org/licenses/>.
-**/
+ **/
 
 #include "Rcpp.h"
 #include <gdtools.h>
@@ -148,10 +148,16 @@ static void docx_metric_info(int c, const pGEcontext gc, double* ascent,
                             double* descent, double* width, pDevDesc dd) {
   DOCX_dev *docx_obj = (DOCX_dev*) dd->deviceSpecific;
 
-  // Convert to string - negative implies unicode code point
-  char str[16];
+  bool Unicode = mbcslocale;
   if (c < 0) {
-    Rf_ucstoutf8(str, (unsigned int) -c);
+    Unicode = TRUE;
+    c = -c;
+  }
+  char str[16];
+  if (!c) {
+    str[0]='M'; str[1]='g'; str[2]=0;
+  } else if (Unicode) {
+    Rf_ucstoutf8(str, (unsigned int) c);
   } else {
     str[0] = (char) c;
     str[1] = '\0';
@@ -184,7 +190,7 @@ static void docx_close(pDevDesc dd) {
 
 
 
-static double docx_strwidth(const char *str, const pGEcontext gc, pDevDesc dd) {
+static double docx_strwidth_utf8(const char *str, const pGEcontext gc, pDevDesc dd) {
   DOCX_dev *docx_obj = (DOCX_dev*) dd->deviceSpecific;
 
   std::string file = fontfile(gc->fontfamily, gc->fontface, docx_obj->user_aliases);
@@ -194,9 +200,12 @@ static double docx_strwidth(const char *str, const pGEcontext gc, pDevDesc dd) {
 
   return fm.width;
 }
+static double docx_strwidth(const char *str, const pGEcontext gc, pDevDesc dd) {
+  return docx_strwidth_utf8(Rf_translateCharUTF8(Rf_mkChar(str)), gc, dd);
+}
 
 
-static double docx_strheight(const char *str, const pGEcontext gc, pDevDesc dd) {
+static double docx_strheight_utf8(const char *str, const pGEcontext gc, pDevDesc dd) {
   DOCX_dev *docx_obj = (DOCX_dev*) dd->deviceSpecific;
   std::string file = fontfile(gc->fontfamily, gc->fontface, docx_obj->user_aliases);
   std::string name = fontname(gc->fontfamily, gc->fontface, docx_obj->system_aliases, docx_obj->user_aliases);
@@ -370,13 +379,13 @@ static void docx_circle(double x, double y, double r, const pGEcontext gc,
 }
 
 
-static void docx_text(double x, double y, const char *str, double rot,
+static void docx_text_utf8(double x, double y, const char *str, double rot,
                      double hadj, const pGEcontext gc, pDevDesc dd) {
   DOCX_dev *docx_obj = (DOCX_dev*) dd->deviceSpecific;
 
   double fs = gc->cex * gc->ps;
-  double w = docx_strwidth(str, gc, dd);
-  double h = docx_strheight(str, gc, dd);
+  double w = docx_strwidth_utf8(str, gc, dd);
+  double h = docx_strheight_utf8(str, gc, dd);
   if( fs*2 < 1.0 ) return;
 
   double corrected_offx = translate_rotate_x(x, y, rot, h, w, hadj) ;
@@ -399,6 +408,11 @@ static void docx_text(double x, double y, const char *str, double rot,
   fputs("</wps:wsp>", docx_obj->file);
 }
 
+static void docx_text(double x, double y, const char *str, double rot,
+                     double hadj, const pGEcontext gc, pDevDesc dd) {
+  return docx_text_utf8(x, y, Rf_translateCharUTF8(Rf_mkChar(str)), rot, hadj, gc, dd);
+}
+
 static void docx_size(double *left, double *right, double *bottom, double *top,
                      pDevDesc dd) {
   *left = dd->left;
@@ -531,8 +545,8 @@ pDevDesc docx_driver_new(std::string filename, int bg, double width, double heig
   // UTF-8 support
   dd->wantSymbolUTF8 = (Rboolean) 1;
   dd->hasTextUTF8 = (Rboolean) 1;
-  dd->textUTF8 = docx_text;
-  dd->strWidthUTF8 = docx_strwidth;
+  dd->textUTF8 = docx_text_utf8;
+  dd->strWidthUTF8 = docx_strwidth_utf8;
 
   // Screen Dimensions in pts
   dd->left = 0;
