@@ -1,6 +1,6 @@
 /*
  * This file is part of rvg.
- * Copyright (c) 2015, David Gohel All rights reserved.
+ * Copyright (c) 2018, David Gohel All rights reserved.
  *
  * rvg is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -13,7 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with rvg. If not, see <httxdr://www.gnu.org/licenses/>.
+ * along with rvg. If not, see <http://www.gnu.org/licenses/>.
 **/
 
 #include "Rcpp.h"
@@ -148,10 +148,16 @@ static void xlsx_metric_info(int c, const pGEcontext gc, double* ascent,
                             double* descent, double* width, pDevDesc dd) {
   XLSX_dev *xlsx_obj = (XLSX_dev*) dd->deviceSpecific;
 
-  // Convert to string - negative implies unicode code point
-  char str[16];
+  bool Unicode = mbcslocale;
   if (c < 0) {
-    Rf_ucstoutf8(str, (unsigned int) -c);
+    Unicode = TRUE;
+    c = -c;
+  }
+  char str[16];
+  if (!c) {
+    str[0]='M'; str[1]='g'; str[2]=0;
+  } else if (Unicode) {
+    Rf_ucstoutf8(str, (unsigned int) c);
   } else {
     str[0] = (char) c;
     str[1] = '\0';
@@ -185,7 +191,7 @@ static void xlsx_close(pDevDesc dd) {
 
 
 
-static double xlsx_strwidth(const char *str, const pGEcontext gc, pDevDesc dd) {
+static double xlsx_strwidth_utf8(const char *str, const pGEcontext gc, pDevDesc dd) {
   XLSX_dev *xlsx_obj = (XLSX_dev*) dd->deviceSpecific;
 
   std::string file = fontfile(gc->fontfamily, gc->fontface, xlsx_obj->user_aliases);
@@ -195,9 +201,12 @@ static double xlsx_strwidth(const char *str, const pGEcontext gc, pDevDesc dd) {
 
   return fm.width;
 }
+static double xlsx_strwidth(const char *str, const pGEcontext gc, pDevDesc dd) {
+  return xlsx_strwidth_utf8(Rf_translateCharUTF8(Rf_mkChar(str)), gc, dd);
+}
 
 
-static double xlsx_strheight(const char *str, const pGEcontext gc, pDevDesc dd) {
+static double xlsx_strheight_utf8(const char *str, const pGEcontext gc, pDevDesc dd) {
   XLSX_dev *xlsx_obj = (XLSX_dev*) dd->deviceSpecific;
 
   std::string file = fontfile(gc->fontfamily, gc->fontface, xlsx_obj->user_aliases);
@@ -386,13 +395,13 @@ static void xlsx_circle(double x, double y, double r, const pGEcontext gc,
 }
 
 
-static void xlsx_text(double x, double y, const char *str, double rot,
+static void xlsx_text_utf8(double x, double y, const char *str, double rot,
                      double hadj, const pGEcontext gc, pDevDesc dd) {
   XLSX_dev *xlsx_obj = (XLSX_dev*) dd->deviceSpecific;
 
   double fs = gc->cex * gc->ps ;
-  double w = xlsx_strwidth(str, gc, dd);
-  double h = xlsx_strheight(str, gc, dd);
+  double w = xlsx_strwidth_utf8(str, gc, dd);
+  double h = xlsx_strheight_utf8(str, gc, dd);
   if( fs*100 < 1.0 ) return;
 
   double corrected_offx = translate_rotate_x(x, y, rot, h, w, hadj) ;
@@ -413,6 +422,11 @@ static void xlsx_text(double x, double y, const char *str, double rot,
   fputs("</xdr:sp>", xlsx_obj->file);
 }
 
+static void xlsx_text(double x, double y, const char *str, double rot,
+                     double hadj, const pGEcontext gc, pDevDesc dd) {
+  return xlsx_text_utf8(x, y, Rf_translateCharUTF8(Rf_mkChar(str)), rot, hadj, gc, dd);
+}
+
 static void xlsx_size(double *left, double *right, double *bottom, double *top,
                      pDevDesc dd) {
   *left = dd->left;
@@ -551,8 +565,8 @@ pDevDesc xlsx_driver_new(std::string filename, int bg, double width, double heig
   // UTF-8 support
   dd->wantSymbolUTF8 = (Rboolean) 1;
   dd->hasTextUTF8 = (Rboolean) 1;
-  dd->textUTF8 = xlsx_text;
-  dd->strWidthUTF8 = xlsx_strwidth;
+  dd->textUTF8 = xlsx_text_utf8;
+  dd->strWidthUTF8 = xlsx_strwidth_utf8;
 
   // Screen Dimensions in pts
   dd->left = 0;
